<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>EditEvent</name>
    <message>
        <source>Edit Event</source>
        <translation>Upravit událost</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Začít na:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Činnost, když předchozí událost ještě běží</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Spustit ihned</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Jako další</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Počkat až do</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Přechod</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Start Transition Type:</source>
        <translation>Typ spuštění přechodu:</translation>
    </message>
    <message>
        <source>No Fade at Segue Out</source>
        <translation>Žádné prolínání při přechodu ven</translation>
    </message>
    <message>
        <source>&amp;Audition</source>
        <translation type="obsolete">&amp;Poslech</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation type="obsolete">P&amp;ozastavit</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation type="obsolete">Za&amp;stavit</translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="obsolete">Začátek</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Edit Marker</source>
        <translation type="unfinished">Upravit značku</translation>
    </message>
    <message>
        <source>Edit Track</source>
        <translation type="unfinished">Upravit stopu</translation>
    </message>
    <message>
        <source>Edit Log Track</source>
        <translation type="unfinished">Upravit stopu zápisu</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Přechod, když předchozí vozík skončí dříve</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="obsolete">Konec</translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation>Zdvojený čas začátku</translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation>Již existuje událost s tímto začátečním časem!</translation>
    </message>
    <message>
        <source>Cart Notes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HourSelector</name>
    <message>
        <source>12a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>12p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11p</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLog</name>
    <message>
        <source>EST TIME</source>
        <translation type="obsolete">ODH. ČAS</translation>
    </message>
    <message>
        <source>LEN</source>
        <translation type="obsolete">DÉLKA</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="obsolete">PŘECHOD</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">VOZÍK</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">NÁZEV</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">UMĚLEC</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">SKUPINA</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="obsolete">ČAS</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="obsolete">ZÁKAZNÍK</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="obsolete">AGENTURA</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="obsolete">ŠTÍTEK</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation type="obsolete">ID ŘÁDKU</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="obsolete">POČÍTADLO</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation type="obsolete">STAV</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <source>Make
Next</source>
        <translation>Jako
další</translation>
    </message>
    <message>
        <source>Modify</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Projíždět</translation>
    </message>
    <message>
        <source>Refresh
Log</source>
        <translation>Obnovit
zápis</translation>
    </message>
    <message>
        <source>Select
Log</source>
        <translation>Vybrat
zápis</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="obsolete">Zápis existuje</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="obsolete">Zápis již existuje!</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>--- konec zápisu ---</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>PŘEHRÁT</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>ZASTAVIT</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>PŘECHOD</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>ZNAČKA</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>STOPA</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>ODKAZ</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[zavedení hudby]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[zavedení přenosu]</translation>
    </message>
    <message>
        <source>CHAIN TO</source>
        <translation>ŘETĚZ K</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[VOZÍK NENALEZEN]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[ŽÁDNÝ PLATNÝ ZÁBĚR NENÍ DOSTUPNÝ]</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[ŽÁDNÝ ZVUK NENÍ DOSTUPNÝ]</translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished">T</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Spustit</translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation>Délka běhu</translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation>Další zastavení:</translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation>Konec zápisu:</translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation>Vybráno:</translation>
    </message>
    <message>
        <source>Audition
Head</source>
        <translation>Začátek
poslechu</translation>
    </message>
    <message>
        <source>Audition
Tail</source>
        <translation>Konec
poslechu</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Len</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Est. Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sch. Time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation type="obsolete">Vybrat zápis</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="obsolete">NÁZEV</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">POPIS</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">SLUŽBA</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Nahrát</translation>
    </message>
    <message>
        <source>Unload</source>
        <translation>Vyložit</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="obsolete">Uložit &amp;jako</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Rename Log</source>
        <translation>Přejmenovat zápis</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log already being edited by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must refresh the log before it can be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogLineBox</name>
    <message>
        <source>STOP</source>
        <translation>ZASTAVIT</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>PŘEHRÁT</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>PŘECHOD</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[VOZÍK NENALEZEN]</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[ŽÁDNÝ ZVUK NENÍ DOSTUPNÝ]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[ŽÁDNÝ PLATNÝ ZÁBĚR NENÍ DOSTUPNÝ]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>ZNAČKA</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>STOPA</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>ODKAZ</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[zavedení hudby]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[zavedení přenosu]</translation>
    </message>
    <message>
        <source>CHAIN</source>
        <translation>ŘETĚZ</translation>
    </message>
    <message>
        <source>T</source>
        <translation type="obsolete">T</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDAirPlay</source>
        <translation>RDAirplay</translation>
    </message>
    <message>
        <source>Multiple instances not allowed!</source>
        <translation>Více instancí není dovoleno!</translation>
    </message>
    <message>
        <source>RDAirPlay - Host:</source>
        <translation type="obsolete">RDAirPlay - Server</translation>
    </message>
    <message>
        <source>Database Error</source>
        <translation type="obsolete">Chyba databáze</translation>
    </message>
    <message>
        <source>ADD</source>
        <translation>PŘIDAT</translation>
    </message>
    <message>
        <source>DEL</source>
        <translation>SMAZAT</translation>
    </message>
    <message>
        <source>MOVE</source>
        <translation>PŘESUNOUT</translation>
    </message>
    <message>
        <source>COPY</source>
        <translation>KOPÍROVAT</translation>
    </message>
    <message>
        <source>Main Log
[--]</source>
        <translation>Hlavní zápis
[--]</translation>
    </message>
    <message>
        <source>Aux 1 Log
[--]</source>
        <translation>Pomocný zápis 1
[--]</translation>
    </message>
    <message>
        <source>Aux 2 Log
[--]</source>
        <translation>Pomocný zápis 2
[--]</translation>
    </message>
    <message>
        <source>Sound
Panel</source>
        <translation>Zvukový
panel</translation>
    </message>
    <message>
        <source>Main Log</source>
        <translation>Hlavní zápis</translation>
    </message>
    <message>
        <source>Aux 1 Log</source>
        <translation>Pomocný zápis 1</translation>
    </message>
    <message>
        <source>Aux 2 Log</source>
        <translation>Pomocný zápis 2</translation>
    </message>
    <message>
        <source>LOG
REFRESHING</source>
        <translation>ZÁPIS
OBNOVEN</translation>
    </message>
    <message>
        <source>Exit RDAirPlay?</source>
        <translation>Ukončit RDAirPlay?</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Memory Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to lock all memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log channel assignments are invalid!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModeDisplay</name>
    <message>
        <source>Operating Mode</source>
        <translation type="unfinished">Operační režim</translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation>Živá pomoc</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatický</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ruční</translation>
    </message>
    <message>
        <source>A1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PostCounter</name>
    <message>
        <source>Next Timed Start</source>
        <translation>Další načasovaný začátek</translation>
    </message>
    <message>
        <source>On Time</source>
        <translation>Přesně na čas</translation>
    </message>
    <message>
        <source>Next Timed Start [--:--:--]</source>
        <translation>Další načasovaný začátek [--:--:--]</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>START</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">ZASTAVIT</translation>
    </message>
    <message>
        <source>PAUSE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RESUME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WHERE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DELETE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOVE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TO?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COPY?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ERROR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StopCounter</name>
    <message>
        <source>Next Stop [none]</source>
        <translation>Další zastavení [žádné]</translation>
    </message>
    <message>
        <source>Next Stop</source>
        <translation>Další zastavení</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Zastaveno</translation>
    </message>
</context>
</TS>
